@@ -27,8 +27,11 @@ extensions = [
     "sphinx_design",
     "sphinx_sitemap",
     "sphinx_contributors",
+    "sphinx_iconify",
 ]
 
+iconify_script_url = ""
+
 extlinks = {
     "user": ("https://github.com/%s", "@%s"),
     "pull": ("https://github.com/authlib/joserfc/pull/%s", "pull request #%s"),
