@@ -7,6 +7,7 @@ from joserfc.errors import (
     MissingCritHeaderError,
 )
 from joserfc.util import to_bytes
+from joserfc.jws import HeaderDict
 from joserfc import jws
 from tests.base import TestFixture
 
@@ -68,20 +69,20 @@ class TestRFC7797(TestFixture):
 
     def test_json_without_protected_header(self):
         header = {"alg": "HS256", "b64": False, "crit": ["b64"]}
-        member = {"header": header}
+        member: HeaderDict = {"header": header}
         value = jws.serialize_json(member, "hello", default_key)
         obj = jws.deserialize_json(value, default_key)
         self.assertTrue(obj.flattened)
         self.assertEqual(obj.headers(), header)
 
     def test_general_json(self):
-        members = [{"protected": {"alg": "HS256"}}]
-        value = jws.serialize_json(members, "hello", default_key)
+        member: HeaderDict = {"protected": {"alg": "HS256"}}
+        value = jws.serialize_json([member], "hello", default_key)
         obj = jws.deserialize_json(value, default_key)
         self.assertFalse(obj.flattened)
 
     def test_json_bad_signature(self):
-        member = {"protected": {"alg": "HS256", "b64": False, "crit": ["b64"]}}
+        member: HeaderDict = {"protected": {"alg": "HS256", "b64": False, "crit": ["b64"]}}
         value = jws.serialize_json(member, "hello", default_key)
         key2 = OctKey.import_key("secret")
         self.assertRaises(BadSignatureError, jws.deserialize_json, value, key2)
